# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class FullyQualifiedScope(object):
    """
    FullyQualifiedScope model.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new FullyQualifiedScope object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param audience:
            The value to assign to the audience property of this FullyQualifiedScope.
        :type audience: str

        :param scope:
            The value to assign to the scope property of this FullyQualifiedScope.
        :type scope: str

        """
        self.swagger_types = {
            'audience': 'str',
            'scope': 'str'
        }

        self.attribute_map = {
            'audience': 'audience',
            'scope': 'scope'
        }

        self._audience = None
        self._scope = None

    @property
    def audience(self):
        """
        **[Required]** Gets the audience of this FullyQualifiedScope.
        Audience for the given scope context.


        :return: The audience of this FullyQualifiedScope.
        :rtype: str
        """
        return self._audience

    @audience.setter
    def audience(self, audience):
        """
        Sets the audience of this FullyQualifiedScope.
        Audience for the given scope context.


        :param audience: The audience of this FullyQualifiedScope.
        :type: str
        """
        self._audience = audience

    @property
    def scope(self):
        """
        **[Required]** Gets the scope of this FullyQualifiedScope.
        Allowed permission scope for the given context.


        :return: The scope of this FullyQualifiedScope.
        :rtype: str
        """
        return self._scope

    @scope.setter
    def scope(self, scope):
        """
        Sets the scope of this FullyQualifiedScope.
        Allowed permission scope for the given context.


        :param scope: The scope of this FullyQualifiedScope.
        :type: str
        """
        self._scope = scope

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ReferenceUsedBy(object):
    """
    Referenced object information.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ReferenceUsedBy object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param key:
            The value to assign to the key property of this ReferenceUsedBy.
        :type key: str

        :param name:
            The value to assign to the name property of this ReferenceUsedBy.
        :type name: str

        :param name_path:
            The value to assign to the name_path property of this ReferenceUsedBy.
        :type name_path: str

        """
        self.swagger_types = {
            'key': 'str',
            'name': 'str',
            'name_path': 'str'
        }

        self.attribute_map = {
            'key': 'key',
            'name': 'name',
            'name_path': 'namePath'
        }

        self._key = None
        self._name = None
        self._name_path = None

    @property
    def key(self):
        """
        Gets the key of this ReferenceUsedBy.
        The key of the published object.


        :return: The key of this ReferenceUsedBy.
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """
        Sets the key of this ReferenceUsedBy.
        The key of the published object.


        :param key: The key of this ReferenceUsedBy.
        :type: str
        """
        self._key = key

    @property
    def name(self):
        """
        Gets the name of this ReferenceUsedBy.
        The name of an published object.


        :return: The name of this ReferenceUsedBy.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ReferenceUsedBy.
        The name of an published object.


        :param name: The name of this ReferenceUsedBy.
        :type: str
        """
        self._name = name

    @property
    def name_path(self):
        """
        Gets the name_path of this ReferenceUsedBy.
        The name path of the published object.


        :return: The name_path of this ReferenceUsedBy.
        :rtype: str
        """
        return self._name_path

    @name_path.setter
    def name_path(self, name_path):
        """
        Sets the name_path of this ReferenceUsedBy.
        The name path of the published object.


        :param name_path: The name_path of this ReferenceUsedBy.
        :type: str
        """
        self._name_path = name_path

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DrgAttachment(object):
    """
    A link between a DRG and VCN. For more information, see
    `Overview of the Networking Service`__.

    **Warning:** Oracle recommends that you avoid using any confidential information when you
    supply string values using the API.

    __ https://docs.cloud.oracle.com/Content/Network/Concepts/overview.htm
    """

    #: A constant which can be used with the lifecycle_state property of a DrgAttachment.
    #: This constant has a value of "ATTACHING"
    LIFECYCLE_STATE_ATTACHING = "ATTACHING"

    #: A constant which can be used with the lifecycle_state property of a DrgAttachment.
    #: This constant has a value of "ATTACHED"
    LIFECYCLE_STATE_ATTACHED = "ATTACHED"

    #: A constant which can be used with the lifecycle_state property of a DrgAttachment.
    #: This constant has a value of "DETACHING"
    LIFECYCLE_STATE_DETACHING = "DETACHING"

    #: A constant which can be used with the lifecycle_state property of a DrgAttachment.
    #: This constant has a value of "DETACHED"
    LIFECYCLE_STATE_DETACHED = "DETACHED"

    def __init__(self, **kwargs):
        """
        Initializes a new DrgAttachment object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param compartment_id:
            The value to assign to the compartment_id property of this DrgAttachment.
        :type compartment_id: str

        :param display_name:
            The value to assign to the display_name property of this DrgAttachment.
        :type display_name: str

        :param drg_id:
            The value to assign to the drg_id property of this DrgAttachment.
        :type drg_id: str

        :param id:
            The value to assign to the id property of this DrgAttachment.
        :type id: str

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this DrgAttachment.
            Allowed values for this property are: "ATTACHING", "ATTACHED", "DETACHING", "DETACHED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param route_table_id:
            The value to assign to the route_table_id property of this DrgAttachment.
        :type route_table_id: str

        :param time_created:
            The value to assign to the time_created property of this DrgAttachment.
        :type time_created: datetime

        :param vcn_id:
            The value to assign to the vcn_id property of this DrgAttachment.
        :type vcn_id: str

        """
        self.swagger_types = {
            'compartment_id': 'str',
            'display_name': 'str',
            'drg_id': 'str',
            'id': 'str',
            'lifecycle_state': 'str',
            'route_table_id': 'str',
            'time_created': 'datetime',
            'vcn_id': 'str'
        }

        self.attribute_map = {
            'compartment_id': 'compartmentId',
            'display_name': 'displayName',
            'drg_id': 'drgId',
            'id': 'id',
            'lifecycle_state': 'lifecycleState',
            'route_table_id': 'routeTableId',
            'time_created': 'timeCreated',
            'vcn_id': 'vcnId'
        }

        self._compartment_id = None
        self._display_name = None
        self._drg_id = None
        self._id = None
        self._lifecycle_state = None
        self._route_table_id = None
        self._time_created = None
        self._vcn_id = None

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this DrgAttachment.
        The OCID of the compartment containing the DRG attachment.


        :return: The compartment_id of this DrgAttachment.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this DrgAttachment.
        The OCID of the compartment containing the DRG attachment.


        :param compartment_id: The compartment_id of this DrgAttachment.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def display_name(self):
        """
        Gets the display_name of this DrgAttachment.
        A user-friendly name. Does not have to be unique, and it's changeable.
        Avoid entering confidential information.


        :return: The display_name of this DrgAttachment.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this DrgAttachment.
        A user-friendly name. Does not have to be unique, and it's changeable.
        Avoid entering confidential information.


        :param display_name: The display_name of this DrgAttachment.
        :type: str
        """
        self._display_name = display_name

    @property
    def drg_id(self):
        """
        **[Required]** Gets the drg_id of this DrgAttachment.
        The OCID of the DRG.


        :return: The drg_id of this DrgAttachment.
        :rtype: str
        """
        return self._drg_id

    @drg_id.setter
    def drg_id(self, drg_id):
        """
        Sets the drg_id of this DrgAttachment.
        The OCID of the DRG.


        :param drg_id: The drg_id of this DrgAttachment.
        :type: str
        """
        self._drg_id = drg_id

    @property
    def id(self):
        """
        **[Required]** Gets the id of this DrgAttachment.
        The DRG attachment's Oracle ID (OCID).


        :return: The id of this DrgAttachment.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this DrgAttachment.
        The DRG attachment's Oracle ID (OCID).


        :param id: The id of this DrgAttachment.
        :type: str
        """
        self._id = id

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this DrgAttachment.
        The DRG attachment's current state.

        Allowed values for this property are: "ATTACHING", "ATTACHED", "DETACHING", "DETACHED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this DrgAttachment.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this DrgAttachment.
        The DRG attachment's current state.


        :param lifecycle_state: The lifecycle_state of this DrgAttachment.
        :type: str
        """
        allowed_values = ["ATTACHING", "ATTACHED", "DETACHING", "DETACHED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def route_table_id(self):
        """
        Gets the route_table_id of this DrgAttachment.
        The OCID of the route table the DRG attachment is using.

        For information about why you would associate a route table with a DRG attachment, see:

          * `Transit Routing: Access to Multiple VCNs in Same Region`__
          * `Transit Routing: Private Access to Oracle Services`__

        __ https://docs.cloud.oracle.com/Content/Network/Tasks/transitrouting.htm
        __ https://docs.cloud.oracle.com/Content/Network/Tasks/transitroutingoracleservices.htm


        :return: The route_table_id of this DrgAttachment.
        :rtype: str
        """
        return self._route_table_id

    @route_table_id.setter
    def route_table_id(self, route_table_id):
        """
        Sets the route_table_id of this DrgAttachment.
        The OCID of the route table the DRG attachment is using.

        For information about why you would associate a route table with a DRG attachment, see:

          * `Transit Routing: Access to Multiple VCNs in Same Region`__
          * `Transit Routing: Private Access to Oracle Services`__

        __ https://docs.cloud.oracle.com/Content/Network/Tasks/transitrouting.htm
        __ https://docs.cloud.oracle.com/Content/Network/Tasks/transitroutingoracleservices.htm


        :param route_table_id: The route_table_id of this DrgAttachment.
        :type: str
        """
        self._route_table_id = route_table_id

    @property
    def time_created(self):
        """
        Gets the time_created of this DrgAttachment.
        The date and time the DRG attachment was created, in the format defined by `RFC3339`__.

        Example: `2016-08-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_created of this DrgAttachment.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this DrgAttachment.
        The date and time the DRG attachment was created, in the format defined by `RFC3339`__.

        Example: `2016-08-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :param time_created: The time_created of this DrgAttachment.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def vcn_id(self):
        """
        **[Required]** Gets the vcn_id of this DrgAttachment.
        The OCID of the VCN.


        :return: The vcn_id of this DrgAttachment.
        :rtype: str
        """
        return self._vcn_id

    @vcn_id.setter
    def vcn_id(self, vcn_id):
        """
        Sets the vcn_id of this DrgAttachment.
        The OCID of the VCN.


        :param vcn_id: The vcn_id of this DrgAttachment.
        :type: str
        """
        self._vcn_id = vcn_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ManagementDashboardSummary(object):
    """
    Summary of the properties of a dashboard.
    """

    #: A constant which can be used with the lifecycle_state property of a ManagementDashboardSummary.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    def __init__(self, **kwargs):
        """
        Initializes a new ManagementDashboardSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param dashboard_id:
            The value to assign to the dashboard_id property of this ManagementDashboardSummary.
        :type dashboard_id: str

        :param display_name:
            The value to assign to the display_name property of this ManagementDashboardSummary.
        :type display_name: str

        :param description:
            The value to assign to the description property of this ManagementDashboardSummary.
        :type description: str

        :param compartment_id:
            The value to assign to the compartment_id property of this ManagementDashboardSummary.
        :type compartment_id: str

        :param is_oob_dashboard:
            The value to assign to the is_oob_dashboard property of this ManagementDashboardSummary.
        :type is_oob_dashboard: bool

        :param created_by:
            The value to assign to the created_by property of this ManagementDashboardSummary.
        :type created_by: str

        :param time_created:
            The value to assign to the time_created property of this ManagementDashboardSummary.
        :type time_created: datetime

        :param updated_by:
            The value to assign to the updated_by property of this ManagementDashboardSummary.
        :type updated_by: str

        :param time_updated:
            The value to assign to the time_updated property of this ManagementDashboardSummary.
        :type time_updated: datetime

        :param metadata_version:
            The value to assign to the metadata_version property of this ManagementDashboardSummary.
        :type metadata_version: str

        :param screen_image:
            The value to assign to the screen_image property of this ManagementDashboardSummary.
        :type screen_image: str

        :param nls:
            The value to assign to the nls property of this ManagementDashboardSummary.
        :type nls: object

        :param type:
            The value to assign to the type property of this ManagementDashboardSummary.
        :type type: str

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this ManagementDashboardSummary.
            Allowed values for this property are: "ACTIVE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this ManagementDashboardSummary.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this ManagementDashboardSummary.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'dashboard_id': 'str',
            'display_name': 'str',
            'description': 'str',
            'compartment_id': 'str',
            'is_oob_dashboard': 'bool',
            'created_by': 'str',
            'time_created': 'datetime',
            'updated_by': 'str',
            'time_updated': 'datetime',
            'metadata_version': 'str',
            'screen_image': 'str',
            'nls': 'object',
            'type': 'str',
            'lifecycle_state': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'dashboard_id': 'dashboardId',
            'display_name': 'displayName',
            'description': 'description',
            'compartment_id': 'compartmentId',
            'is_oob_dashboard': 'isOobDashboard',
            'created_by': 'createdBy',
            'time_created': 'timeCreated',
            'updated_by': 'updatedBy',
            'time_updated': 'timeUpdated',
            'metadata_version': 'metadataVersion',
            'screen_image': 'screenImage',
            'nls': 'nls',
            'type': 'type',
            'lifecycle_state': 'lifecycleState',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._dashboard_id = None
        self._display_name = None
        self._description = None
        self._compartment_id = None
        self._is_oob_dashboard = None
        self._created_by = None
        self._time_created = None
        self._updated_by = None
        self._time_updated = None
        self._metadata_version = None
        self._screen_image = None
        self._nls = None
        self._type = None
        self._lifecycle_state = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def dashboard_id(self):
        """
        **[Required]** Gets the dashboard_id of this ManagementDashboardSummary.
        ID of the dashboard.


        :return: The dashboard_id of this ManagementDashboardSummary.
        :rtype: str
        """
        return self._dashboard_id

    @dashboard_id.setter
    def dashboard_id(self, dashboard_id):
        """
        Sets the dashboard_id of this ManagementDashboardSummary.
        ID of the dashboard.


        :param dashboard_id: The dashboard_id of this ManagementDashboardSummary.
        :type: str
        """
        self._dashboard_id = dashboard_id

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this ManagementDashboardSummary.
        Display name of the dashboard.


        :return: The display_name of this ManagementDashboardSummary.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this ManagementDashboardSummary.
        Display name of the dashboard.


        :param display_name: The display_name of this ManagementDashboardSummary.
        :type: str
        """
        self._display_name = display_name

    @property
    def description(self):
        """
        **[Required]** Gets the description of this ManagementDashboardSummary.
        Description of the dashboard.


        :return: The description of this ManagementDashboardSummary.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this ManagementDashboardSummary.
        Description of the dashboard.


        :param description: The description of this ManagementDashboardSummary.
        :type: str
        """
        self._description = description

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this ManagementDashboardSummary.
        OCID of the compartment in which the dashboard resides.


        :return: The compartment_id of this ManagementDashboardSummary.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this ManagementDashboardSummary.
        OCID of the compartment in which the dashboard resides.


        :param compartment_id: The compartment_id of this ManagementDashboardSummary.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def is_oob_dashboard(self):
        """
        **[Required]** Gets the is_oob_dashboard of this ManagementDashboardSummary.
        Determines whether the dashboard is an Out-of-the-Box (OOB) dashboard. Note that OOB dashboards are only provided by Oracle and cannot be modified.


        :return: The is_oob_dashboard of this ManagementDashboardSummary.
        :rtype: bool
        """
        return self._is_oob_dashboard

    @is_oob_dashboard.setter
    def is_oob_dashboard(self, is_oob_dashboard):
        """
        Sets the is_oob_dashboard of this ManagementDashboardSummary.
        Determines whether the dashboard is an Out-of-the-Box (OOB) dashboard. Note that OOB dashboards are only provided by Oracle and cannot be modified.


        :param is_oob_dashboard: The is_oob_dashboard of this ManagementDashboardSummary.
        :type: bool
        """
        self._is_oob_dashboard = is_oob_dashboard

    @property
    def created_by(self):
        """
        **[Required]** Gets the created_by of this ManagementDashboardSummary.
        User who created the dashboard.


        :return: The created_by of this ManagementDashboardSummary.
        :rtype: str
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """
        Sets the created_by of this ManagementDashboardSummary.
        User who created the dashboard.


        :param created_by: The created_by of this ManagementDashboardSummary.
        :type: str
        """
        self._created_by = created_by

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this ManagementDashboardSummary.
        Date and time the dashboard was created.


        :return: The time_created of this ManagementDashboardSummary.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this ManagementDashboardSummary.
        Date and time the dashboard was created.


        :param time_created: The time_created of this ManagementDashboardSummary.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def updated_by(self):
        """
        **[Required]** Gets the updated_by of this ManagementDashboardSummary.
        User who updated the dashboard.


        :return: The updated_by of this ManagementDashboardSummary.
        :rtype: str
        """
        return self._updated_by

    @updated_by.setter
    def updated_by(self, updated_by):
        """
        Sets the updated_by of this ManagementDashboardSummary.
        User who updated the dashboard.


        :param updated_by: The updated_by of this ManagementDashboardSummary.
        :type: str
        """
        self._updated_by = updated_by

    @property
    def time_updated(self):
        """
        **[Required]** Gets the time_updated of this ManagementDashboardSummary.
        Date and time the dashboard was updated.


        :return: The time_updated of this ManagementDashboardSummary.
        :rtype: datetime
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this ManagementDashboardSummary.
        Date and time the dashboard was updated.


        :param time_updated: The time_updated of this ManagementDashboardSummary.
        :type: datetime
        """
        self._time_updated = time_updated

    @property
    def metadata_version(self):
        """
        **[Required]** Gets the metadata_version of this ManagementDashboardSummary.
        Version of the metadata.


        :return: The metadata_version of this ManagementDashboardSummary.
        :rtype: str
        """
        return self._metadata_version

    @metadata_version.setter
    def metadata_version(self, metadata_version):
        """
        Sets the metadata_version of this ManagementDashboardSummary.
        Version of the metadata.


        :param metadata_version: The metadata_version of this ManagementDashboardSummary.
        :type: str
        """
        self._metadata_version = metadata_version

    @property
    def screen_image(self):
        """
        **[Required]** Gets the screen_image of this ManagementDashboardSummary.
        Screen image of the dashboard.


        :return: The screen_image of this ManagementDashboardSummary.
        :rtype: str
        """
        return self._screen_image

    @screen_image.setter
    def screen_image(self, screen_image):
        """
        Sets the screen_image of this ManagementDashboardSummary.
        Screen image of the dashboard.


        :param screen_image: The screen_image of this ManagementDashboardSummary.
        :type: str
        """
        self._screen_image = screen_image

    @property
    def nls(self):
        """
        **[Required]** Gets the nls of this ManagementDashboardSummary.
        JSON that contains internationalization options.


        :return: The nls of this ManagementDashboardSummary.
        :rtype: object
        """
        return self._nls

    @nls.setter
    def nls(self, nls):
        """
        Sets the nls of this ManagementDashboardSummary.
        JSON that contains internationalization options.


        :param nls: The nls of this ManagementDashboardSummary.
        :type: object
        """
        self._nls = nls

    @property
    def type(self):
        """
        **[Required]** Gets the type of this ManagementDashboardSummary.
        Type of dashboard. NORMAL denotes a single dashboard and SET denotes a dashboard set.


        :return: The type of this ManagementDashboardSummary.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this ManagementDashboardSummary.
        Type of dashboard. NORMAL denotes a single dashboard and SET denotes a dashboard set.


        :param type: The type of this ManagementDashboardSummary.
        :type: str
        """
        self._type = type

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this ManagementDashboardSummary.
        Current lifecycle state of the dashboard.

        Allowed values for this property are: "ACTIVE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this ManagementDashboardSummary.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this ManagementDashboardSummary.
        Current lifecycle state of the dashboard.


        :param lifecycle_state: The lifecycle_state of this ManagementDashboardSummary.
        :type: str
        """
        allowed_values = ["ACTIVE"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def freeform_tags(self):
        """
        **[Required]** Gets the freeform_tags of this ManagementDashboardSummary.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :return: The freeform_tags of this ManagementDashboardSummary.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this ManagementDashboardSummary.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :param freeform_tags: The freeform_tags of this ManagementDashboardSummary.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        **[Required]** Gets the defined_tags of this ManagementDashboardSummary.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :return: The defined_tags of this ManagementDashboardSummary.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this ManagementDashboardSummary.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :param defined_tags: The defined_tags of this ManagementDashboardSummary.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from __future__ import absolute_import

from .database_details import DatabaseDetails
from .database_insight_summary import DatabaseInsightSummary
from .database_insights import DatabaseInsights
from .database_insights_collection import DatabaseInsightsCollection
from .historical_data_item import HistoricalDataItem
from .ingest_sql_bucket_details import IngestSqlBucketDetails
from .ingest_sql_bucket_response_details import IngestSqlBucketResponseDetails
from .ingest_sql_plan_lines_details import IngestSqlPlanLinesDetails
from .ingest_sql_plan_lines_response_details import IngestSqlPlanLinesResponseDetails
from .ingest_sql_text_details import IngestSqlTextDetails
from .ingest_sql_text_response_details import IngestSqlTextResponseDetails
from .projected_data_item import ProjectedDataItem
from .resource_capacity_trend_aggregation import ResourceCapacityTrendAggregation
from .resource_insight_current_utilization import ResourceInsightCurrentUtilization
from .resource_insight_projected_utilization import ResourceInsightProjectedUtilization
from .resource_insight_projected_utilization_item import ResourceInsightProjectedUtilizationItem
from .resource_statistics import ResourceStatistics
from .resource_statistics_aggregation import ResourceStatisticsAggregation
from .resource_usage_trend_aggregation import ResourceUsageTrendAggregation
from .sql_bucket import SqlBucket
from .sql_insight_aggregation import SqlInsightAggregation
from .sql_insight_aggregation_collection import SqlInsightAggregationCollection
from .sql_insight_thresholds import SqlInsightThresholds
from .sql_inventory import SqlInventory
from .sql_plan_collection import SqlPlanCollection
from .sql_plan_insight_aggregation import SqlPlanInsightAggregation
from .sql_plan_insight_aggregation_collection import SqlPlanInsightAggregationCollection
from .sql_plan_insights import SqlPlanInsights
from .sql_plan_line import SqlPlanLine
from .sql_plan_summary import SqlPlanSummary
from .sql_response_time_distribution_aggregation import SqlResponseTimeDistributionAggregation
from .sql_response_time_distribution_aggregation_collection import SqlResponseTimeDistributionAggregationCollection
from .sql_search_collection import SqlSearchCollection
from .sql_search_summary import SqlSearchSummary
from .sql_statistic_aggregation import SqlStatisticAggregation
from .sql_statistic_aggregation_collection import SqlStatisticAggregationCollection
from .sql_statistics import SqlStatistics
from .sql_statistics_time_series import SqlStatisticsTimeSeries
from .sql_statistics_time_series_aggregation import SqlStatisticsTimeSeriesAggregation
from .sql_statistics_time_series_aggregation_collection import SqlStatisticsTimeSeriesAggregationCollection
from .sql_statistics_time_series_by_plan_aggregation import SqlStatisticsTimeSeriesByPlanAggregation
from .sql_statistics_time_series_by_plan_aggregation_collection import SqlStatisticsTimeSeriesByPlanAggregationCollection
from .sql_text import SqlText
from .sql_text_collection import SqlTextCollection
from .sql_text_summary import SqlTextSummary
from .summarize_database_insight_resource_capacity_trend_aggregation_collection import SummarizeDatabaseInsightResourceCapacityTrendAggregationCollection
from .summarize_database_insight_resource_forecast_trend_aggregation import SummarizeDatabaseInsightResourceForecastTrendAggregation
from .summarize_database_insight_resource_statistics_aggregation_collection import SummarizeDatabaseInsightResourceStatisticsAggregationCollection
from .summarize_database_insight_resource_usage_aggregation import SummarizeDatabaseInsightResourceUsageAggregation
from .summarize_database_insight_resource_usage_trend_aggregation_collection import SummarizeDatabaseInsightResourceUsageTrendAggregationCollection
from .summarize_database_insight_resource_utilization_insight_aggregation import SummarizeDatabaseInsightResourceUtilizationInsightAggregation

# Maps type names to classes for opsi services.
opsi_type_mapping = {
    "DatabaseDetails": DatabaseDetails,
    "DatabaseInsightSummary": DatabaseInsightSummary,
    "DatabaseInsights": DatabaseInsights,
    "DatabaseInsightsCollection": DatabaseInsightsCollection,
    "HistoricalDataItem": HistoricalDataItem,
    "IngestSqlBucketDetails": IngestSqlBucketDetails,
    "IngestSqlBucketResponseDetails": IngestSqlBucketResponseDetails,
    "IngestSqlPlanLinesDetails": IngestSqlPlanLinesDetails,
    "IngestSqlPlanLinesResponseDetails": IngestSqlPlanLinesResponseDetails,
    "IngestSqlTextDetails": IngestSqlTextDetails,
    "IngestSqlTextResponseDetails": IngestSqlTextResponseDetails,
    "ProjectedDataItem": ProjectedDataItem,
    "ResourceCapacityTrendAggregation": ResourceCapacityTrendAggregation,
    "ResourceInsightCurrentUtilization": ResourceInsightCurrentUtilization,
    "ResourceInsightProjectedUtilization": ResourceInsightProjectedUtilization,
    "ResourceInsightProjectedUtilizationItem": ResourceInsightProjectedUtilizationItem,
    "ResourceStatistics": ResourceStatistics,
    "ResourceStatisticsAggregation": ResourceStatisticsAggregation,
    "ResourceUsageTrendAggregation": ResourceUsageTrendAggregation,
    "SqlBucket": SqlBucket,
    "SqlInsightAggregation": SqlInsightAggregation,
    "SqlInsightAggregationCollection": SqlInsightAggregationCollection,
    "SqlInsightThresholds": SqlInsightThresholds,
    "SqlInventory": SqlInventory,
    "SqlPlanCollection": SqlPlanCollection,
    "SqlPlanInsightAggregation": SqlPlanInsightAggregation,
    "SqlPlanInsightAggregationCollection": SqlPlanInsightAggregationCollection,
    "SqlPlanInsights": SqlPlanInsights,
    "SqlPlanLine": SqlPlanLine,
    "SqlPlanSummary": SqlPlanSummary,
    "SqlResponseTimeDistributionAggregation": SqlResponseTimeDistributionAggregation,
    "SqlResponseTimeDistributionAggregationCollection": SqlResponseTimeDistributionAggregationCollection,
    "SqlSearchCollection": SqlSearchCollection,
    "SqlSearchSummary": SqlSearchSummary,
    "SqlStatisticAggregation": SqlStatisticAggregation,
    "SqlStatisticAggregationCollection": SqlStatisticAggregationCollection,
    "SqlStatistics": SqlStatistics,
    "SqlStatisticsTimeSeries": SqlStatisticsTimeSeries,
    "SqlStatisticsTimeSeriesAggregation": SqlStatisticsTimeSeriesAggregation,
    "SqlStatisticsTimeSeriesAggregationCollection": SqlStatisticsTimeSeriesAggregationCollection,
    "SqlStatisticsTimeSeriesByPlanAggregation": SqlStatisticsTimeSeriesByPlanAggregation,
    "SqlStatisticsTimeSeriesByPlanAggregationCollection": SqlStatisticsTimeSeriesByPlanAggregationCollection,
    "SqlText": SqlText,
    "SqlTextCollection": SqlTextCollection,
    "SqlTextSummary": SqlTextSummary,
    "SummarizeDatabaseInsightResourceCapacityTrendAggregationCollection": SummarizeDatabaseInsightResourceCapacityTrendAggregationCollection,
    "SummarizeDatabaseInsightResourceForecastTrendAggregation": SummarizeDatabaseInsightResourceForecastTrendAggregation,
    "SummarizeDatabaseInsightResourceStatisticsAggregationCollection": SummarizeDatabaseInsightResourceStatisticsAggregationCollection,
    "SummarizeDatabaseInsightResourceUsageAggregation": SummarizeDatabaseInsightResourceUsageAggregation,
    "SummarizeDatabaseInsightResourceUsageTrendAggregationCollection": SummarizeDatabaseInsightResourceUsageTrendAggregationCollection,
    "SummarizeDatabaseInsightResourceUtilizationInsightAggregation": SummarizeDatabaseInsightResourceUtilizationInsightAggregation
}



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DatabaseUpgradeSourceBase(object):
    """
    Details of upgrade source using which the database is upgraded.
    **Warning:** Oracle recommends that you avoid using any confidential information when you supply string values using the API.
    """

    #: A constant which can be used with the source property of a DatabaseUpgradeSourceBase.
    #: This constant has a value of "DB_HOME"
    SOURCE_DB_HOME = "DB_HOME"

    #: A constant which can be used with the source property of a DatabaseUpgradeSourceBase.
    #: This constant has a value of "DB_VERSION"
    SOURCE_DB_VERSION = "DB_VERSION"

    #: A constant which can be used with the source property of a DatabaseUpgradeSourceBase.
    #: This constant has a value of "DB_SOFTWARE_IMAGE"
    SOURCE_DB_SOFTWARE_IMAGE = "DB_SOFTWARE_IMAGE"

    def __init__(self, **kwargs):
        """
        Initializes a new DatabaseUpgradeSourceBase object with values from keyword arguments. This class has the following subclasses and if you are using this class as input
        to a service operations then you should favor using a subclass over the base class:

        * :class:`~oci.database.models.DatabaseUpgradeWithDbHomeDetails`
        * :class:`~oci.database.models.DatabaseUpgradeWithDatabaseSoftwareImageDetails`
        * :class:`~oci.database.models.DatabaseUpgradeWithDbVersionDetails`

        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param source:
            The value to assign to the source property of this DatabaseUpgradeSourceBase.
            Allowed values for this property are: "DB_HOME", "DB_VERSION", "DB_SOFTWARE_IMAGE"
        :type source: str

        """
        self.swagger_types = {
            'source': 'str'
        }

        self.attribute_map = {
            'source': 'source'
        }

        self._source = None

    @staticmethod
    def get_subtype(object_dictionary):
        """
        Given the hash representation of a subtype of this class,
        use the info in the hash to return the class of the subtype.
        """
        type = object_dictionary['source']

        if type == 'DB_HOME':
            return 'DatabaseUpgradeWithDbHomeDetails'

        if type == 'DB_SOFTWARE_IMAGE':
            return 'DatabaseUpgradeWithDatabaseSoftwareImageDetails'

        if type == 'DB_VERSION':
            return 'DatabaseUpgradeWithDbVersionDetails'
        else:
            return 'DatabaseUpgradeSourceBase'

    @property
    def source(self):
        """
        Gets the source of this DatabaseUpgradeSourceBase.
        The source of the database upgrade
        Use 'DB_HOME' for using existing db home to upgrade the database
        Use 'DB_VERSION' for using database version to upgrade the database
        Use 'DB_SOFTWARE_IMAGE' for using database software image to upgrade the database

        Allowed values for this property are: "DB_HOME", "DB_VERSION", "DB_SOFTWARE_IMAGE"


        :return: The source of this DatabaseUpgradeSourceBase.
        :rtype: str
        """
        return self._source

    @source.setter
    def source(self, source):
        """
        Sets the source of this DatabaseUpgradeSourceBase.
        The source of the database upgrade
        Use 'DB_HOME' for using existing db home to upgrade the database
        Use 'DB_VERSION' for using database version to upgrade the database
        Use 'DB_SOFTWARE_IMAGE' for using database software image to upgrade the database


        :param source: The source of this DatabaseUpgradeSourceBase.
        :type: str
        """
        allowed_values = ["DB_HOME", "DB_VERSION", "DB_SOFTWARE_IMAGE"]
        if not value_allowed_none_or_none_sentinel(source, allowed_values):
            raise ValueError(
                "Invalid value for `source`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._source = source

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class SqlPlanInsights(object):
    """
    Represents collection of SQL Plan Insights.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new SqlPlanInsights object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param text:
            The value to assign to the text property of this SqlPlanInsights.
        :type text: str

        :param value:
            The value to assign to the value property of this SqlPlanInsights.
        :type value: int

        :param category:
            The value to assign to the category property of this SqlPlanInsights.
        :type category: str

        """
        self.swagger_types = {
            'text': 'str',
            'value': 'int',
            'category': 'str'
        }

        self.attribute_map = {
            'text': 'text',
            'value': 'value',
            'category': 'category'
        }

        self._text = None
        self._value = None
        self._category = None

    @property
    def text(self):
        """
        **[Required]** Gets the text of this SqlPlanInsights.
        SQL Plan Insight text.
        For example `Number of Plans Used`, `Most Executed Plan`,
          `Best Performing Plan`, `Worst Performing Plan`,
          `Plan With Most IO`,
          `Plan with Most CPU`


        :return: The text of this SqlPlanInsights.
        :rtype: str
        """
        return self._text

    @text.setter
    def text(self, text):
        """
        Sets the text of this SqlPlanInsights.
        SQL Plan Insight text.
        For example `Number of Plans Used`, `Most Executed Plan`,
          `Best Performing Plan`, `Worst Performing Plan`,
          `Plan With Most IO`,
          `Plan with Most CPU`


        :param text: The text of this SqlPlanInsights.
        :type: str
        """
        self._text = text

    @property
    def value(self):
        """
        **[Required]** Gets the value of this SqlPlanInsights.
        SQL execution plan hash value for a given insight. For example `Most Executed Plan` insight will have value as \"3975467901\"


        :return: The value of this SqlPlanInsights.
        :rtype: int
        """
        return self._value

    @value.setter
    def value(self, value):
        """
        Sets the value of this SqlPlanInsights.
        SQL execution plan hash value for a given insight. For example `Most Executed Plan` insight will have value as \"3975467901\"


        :param value: The value of this SqlPlanInsights.
        :type: int
        """
        self._value = value

    @property
    def category(self):
        """
        **[Required]** Gets the category of this SqlPlanInsights.
        SQL Insight category. For example PLANS_USED, MOST_EXECUTED, BEST_PERFORMER, WORST_PERFORMER, MOST_CPU or MOST_IO.


        :return: The category of this SqlPlanInsights.
        :rtype: str
        """
        return self._category

    @category.setter
    def category(self, category):
        """
        Sets the category of this SqlPlanInsights.
        SQL Insight category. For example PLANS_USED, MOST_EXECUTED, BEST_PERFORMER, WORST_PERFORMER, MOST_CPU or MOST_IO.


        :param category: The category of this SqlPlanInsights.
        :type: str
        """
        self._category = category

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CloudExadataInfrastructure(object):
    """
    Details of the cloud Exadata infrastructure resource. Applies to Exadata Cloud Service instances only.
    """

    #: A constant which can be used with the lifecycle_state property of a CloudExadataInfrastructure.
    #: This constant has a value of "PROVISIONING"
    LIFECYCLE_STATE_PROVISIONING = "PROVISIONING"

    #: A constant which can be used with the lifecycle_state property of a CloudExadataInfrastructure.
    #: This constant has a value of "AVAILABLE"
    LIFECYCLE_STATE_AVAILABLE = "AVAILABLE"

    #: A constant which can be used with the lifecycle_state property of a CloudExadataInfrastructure.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    #: A constant which can be used with the lifecycle_state property of a CloudExadataInfrastructure.
    #: This constant has a value of "TERMINATING"
    LIFECYCLE_STATE_TERMINATING = "TERMINATING"

    #: A constant which can be used with the lifecycle_state property of a CloudExadataInfrastructure.
    #: This constant has a value of "TERMINATED"
    LIFECYCLE_STATE_TERMINATED = "TERMINATED"

    #: A constant which can be used with the lifecycle_state property of a CloudExadataInfrastructure.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    #: A constant which can be used with the lifecycle_state property of a CloudExadataInfrastructure.
    #: This constant has a value of "MAINTENANCE_IN_PROGRESS"
    LIFECYCLE_STATE_MAINTENANCE_IN_PROGRESS = "MAINTENANCE_IN_PROGRESS"

    def __init__(self, **kwargs):
        """
        Initializes a new CloudExadataInfrastructure object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this CloudExadataInfrastructure.
        :type id: str

        :param compartment_id:
            The value to assign to the compartment_id property of this CloudExadataInfrastructure.
        :type compartment_id: str

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this CloudExadataInfrastructure.
            Allowed values for this property are: "PROVISIONING", "AVAILABLE", "UPDATING", "TERMINATING", "TERMINATED", "FAILED", "MAINTENANCE_IN_PROGRESS", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param display_name:
            The value to assign to the display_name property of this CloudExadataInfrastructure.
        :type display_name: str

        :param shape:
            The value to assign to the shape property of this CloudExadataInfrastructure.
        :type shape: str

        :param availability_domain:
            The value to assign to the availability_domain property of this CloudExadataInfrastructure.
        :type availability_domain: str

        :param compute_count:
            The value to assign to the compute_count property of this CloudExadataInfrastructure.
        :type compute_count: int

        :param storage_count:
            The value to assign to the storage_count property of this CloudExadataInfrastructure.
        :type storage_count: int

        :param total_storage_size_in_gbs:
            The value to assign to the total_storage_size_in_gbs property of this CloudExadataInfrastructure.
        :type total_storage_size_in_gbs: int

        :param available_storage_size_in_gbs:
            The value to assign to the available_storage_size_in_gbs property of this CloudExadataInfrastructure.
        :type available_storage_size_in_gbs: int

        :param time_created:
            The value to assign to the time_created property of this CloudExadataInfrastructure.
        :type time_created: datetime

        :param lifecycle_details:
            The value to assign to the lifecycle_details property of this CloudExadataInfrastructure.
        :type lifecycle_details: str

        :param maintenance_window:
            The value to assign to the maintenance_window property of this CloudExadataInfrastructure.
        :type maintenance_window: MaintenanceWindow

        :param last_maintenance_run_id:
            The value to assign to the last_maintenance_run_id property of this CloudExadataInfrastructure.
        :type last_maintenance_run_id: str

        :param next_maintenance_run_id:
            The value to assign to the next_maintenance_run_id property of this CloudExadataInfrastructure.
        :type next_maintenance_run_id: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this CloudExadataInfrastructure.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this CloudExadataInfrastructure.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'id': 'str',
            'compartment_id': 'str',
            'lifecycle_state': 'str',
            'display_name': 'str',
            'shape': 'str',
            'availability_domain': 'str',
            'compute_count': 'int',
            'storage_count': 'int',
            'total_storage_size_in_gbs': 'int',
            'available_storage_size_in_gbs': 'int',
            'time_created': 'datetime',
            'lifecycle_details': 'str',
            'maintenance_window': 'MaintenanceWindow',
            'last_maintenance_run_id': 'str',
            'next_maintenance_run_id': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'id': 'id',
            'compartment_id': 'compartmentId',
            'lifecycle_state': 'lifecycleState',
            'display_name': 'displayName',
            'shape': 'shape',
            'availability_domain': 'availabilityDomain',
            'compute_count': 'computeCount',
            'storage_count': 'storageCount',
            'total_storage_size_in_gbs': 'totalStorageSizeInGBs',
            'available_storage_size_in_gbs': 'availableStorageSizeInGBs',
            'time_created': 'timeCreated',
            'lifecycle_details': 'lifecycleDetails',
            'maintenance_window': 'maintenanceWindow',
            'last_maintenance_run_id': 'lastMaintenanceRunId',
            'next_maintenance_run_id': 'nextMaintenanceRunId',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._id = None
        self._compartment_id = None
        self._lifecycle_state = None
        self._display_name = None
        self._shape = None
        self._availability_domain = None
        self._compute_count = None
        self._storage_count = None
        self._total_storage_size_in_gbs = None
        self._available_storage_size_in_gbs = None
        self._time_created = None
        self._lifecycle_details = None
        self._maintenance_window = None
        self._last_maintenance_run_id = None
        self._next_maintenance_run_id = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this CloudExadataInfrastructure.
        The `OCID`__ of the cloud Exadata infrastructure resource.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The id of this CloudExadataInfrastructure.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this CloudExadataInfrastructure.
        The `OCID`__ of the cloud Exadata infrastructure resource.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param id: The id of this CloudExadataInfrastructure.
        :type: str
        """
        self._id = id

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this CloudExadataInfrastructure.
        The `OCID`__ of the compartment.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this CloudExadataInfrastructure.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this CloudExadataInfrastructure.
        The `OCID`__ of the compartment.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this CloudExadataInfrastructure.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this CloudExadataInfrastructure.
        The current lifecycle state of the cloud Exadata infrastructure resource.

        Allowed values for this property are: "PROVISIONING", "AVAILABLE", "UPDATING", "TERMINATING", "TERMINATED", "FAILED", "MAINTENANCE_IN_PROGRESS", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this CloudExadataInfrastructure.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this CloudExadataInfrastructure.
        The current lifecycle state of the cloud Exadata infrastructure resource.


        :param lifecycle_state: The lifecycle_state of this CloudExadataInfrastructure.
        :type: str
        """
        allowed_values = ["PROVISIONING", "AVAILABLE", "UPDATING", "TERMINATING", "TERMINATED", "FAILED", "MAINTENANCE_IN_PROGRESS"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this CloudExadataInfrastructure.
        The user-friendly name for the cloud Exadata infrastructure resource. The name does not need to be unique.


        :return: The display_name of this CloudExadataInfrastructure.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this CloudExadataInfrastructure.
        The user-friendly name for the cloud Exadata infrastructure resource. The name does not need to be unique.


        :param display_name: The display_name of this CloudExadataInfrastructure.
        :type: str
        """
        self._display_name = display_name

    @property
    def shape(self):
        """
        **[Required]** Gets the shape of this CloudExadataInfrastructure.
        The model name of the cloud Exadata infrastructure resource.


        :return: The shape of this CloudExadataInfrastructure.
        :rtype: str
        """
        return self._shape

    @shape.setter
    def shape(self, shape):
        """
        Sets the shape of this CloudExadataInfrastructure.
        The model name of the cloud Exadata infrastructure resource.


        :param shape: The shape of this CloudExadataInfrastructure.
        :type: str
        """
        self._shape = shape

    @property
    def availability_domain(self):
        """
        **[Required]** Gets the availability_domain of this CloudExadataInfrastructure.
        The name of the availability domain that the cloud Exadata infrastructure resource is located in.


        :return: The availability_domain of this CloudExadataInfrastructure.
        :rtype: str
        """
        return self._availability_domain

    @availability_domain.setter
    def availability_domain(self, availability_domain):
        """
        Sets the availability_domain of this CloudExadataInfrastructure.
        The name of the availability domain that the cloud Exadata infrastructure resource is located in.


        :param availability_domain: The availability_domain of this CloudExadataInfrastructure.
        :type: str
        """
        self._availability_domain = availability_domain

    @property
    def compute_count(self):
        """
        Gets the compute_count of this CloudExadataInfrastructure.
        The number of compute servers for the cloud Exadata infrastructure.


        :return: The compute_count of this CloudExadataInfrastructure.
        :rtype: int
        """
        return self._compute_count

    @compute_count.setter
    def compute_count(self, compute_count):
        """
        Sets the compute_count of this CloudExadataInfrastructure.
        The number of compute servers for the cloud Exadata infrastructure.


        :param compute_count: The compute_count of this CloudExadataInfrastructure.
        :type: int
        """
        self._compute_count = compute_count

    @property
    def storage_count(self):
        """
        Gets the storage_count of this CloudExadataInfrastructure.
        The number of storage servers for the cloud Exadata infrastructure.


        :return: The storage_count of this CloudExadataInfrastructure.
        :rtype: int
        """
        return self._storage_count

    @storage_count.setter
    def storage_count(self, storage_count):
        """
        Sets the storage_count of this CloudExadataInfrastructure.
        The number of storage servers for the cloud Exadata infrastructure.


        :param storage_count: The storage_count of this CloudExadataInfrastructure.
        :type: int
        """
        self._storage_count = storage_count

    @property
    def total_storage_size_in_gbs(self):
        """
        Gets the total_storage_size_in_gbs of this CloudExadataInfrastructure.
        The total storage allocated to the cloud Exadata infrastructure resource, in gigabytes (GB).


        :return: The total_storage_size_in_gbs of this CloudExadataInfrastructure.
        :rtype: int
        """
        return self._total_storage_size_in_gbs

    @total_storage_size_in_gbs.setter
    def total_storage_size_in_gbs(self, total_storage_size_in_gbs):
        """
        Sets the total_storage_size_in_gbs of this CloudExadataInfrastructure.
        The total storage allocated to the cloud Exadata infrastructure resource, in gigabytes (GB).


        :param total_storage_size_in_gbs: The total_storage_size_in_gbs of this CloudExadataInfrastructure.
        :type: int
        """
        self._total_storage_size_in_gbs = total_storage_size_in_gbs

    @property
    def available_storage_size_in_gbs(self):
        """
        Gets the available_storage_size_in_gbs of this CloudExadataInfrastructure.
        The available storage can be allocated to the cloud Exadata infrastructure resource, in gigabytes (GB).


        :return: The available_storage_size_in_gbs of this CloudExadataInfrastructure.
        :rtype: int
        """
        return self._available_storage_size_in_gbs

    @available_storage_size_in_gbs.setter
    def available_storage_size_in_gbs(self, available_storage_size_in_gbs):
        """
        Sets the available_storage_size_in_gbs of this CloudExadataInfrastructure.
        The available storage can be allocated to the cloud Exadata infrastructure resource, in gigabytes (GB).


        :param available_storage_size_in_gbs: The available_storage_size_in_gbs of this CloudExadataInfrastructure.
        :type: int
        """
        self._available_storage_size_in_gbs = available_storage_size_in_gbs

    @property
    def time_created(self):
        """
        Gets the time_created of this CloudExadataInfrastructure.
        The date and time the cloud Exadata infrastructure resource was created.


        :return: The time_created of this CloudExadataInfrastructure.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this CloudExadataInfrastructure.
        The date and time the cloud Exadata infrastructure resource was created.


        :param time_created: The time_created of this CloudExadataInfrastructure.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def lifecycle_details(self):
        """
        Gets the lifecycle_details of this CloudExadataInfrastructure.
        Additional information about the current lifecycle state.


        :return: The lifecycle_details of this CloudExadataInfrastructure.
        :rtype: str
        """
        return self._lifecycle_details

    @lifecycle_details.setter
    def lifecycle_details(self, lifecycle_details):
        """
        Sets the lifecycle_details of this CloudExadataInfrastructure.
        Additional information about the current lifecycle state.


        :param lifecycle_details: The lifecycle_details of this CloudExadataInfrastructure.
        :type: str
        """
        self._lifecycle_details = lifecycle_details

    @property
    def maintenance_window(self):
        """
        Gets the maintenance_window of this CloudExadataInfrastructure.

        :return: The maintenance_window of this CloudExadataInfrastructure.
        :rtype: MaintenanceWindow
        """
        return self._maintenance_window

    @maintenance_window.setter
    def maintenance_window(self, maintenance_window):
        """
        Sets the maintenance_window of this CloudExadataInfrastructure.

        :param maintenance_window: The maintenance_window of this CloudExadataInfrastructure.
        :type: MaintenanceWindow
        """
        self._maintenance_window = maintenance_window

    @property
    def last_maintenance_run_id(self):
        """
        Gets the last_maintenance_run_id of this CloudExadataInfrastructure.
        The `OCID`__ of the last maintenance run.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The last_maintenance_run_id of this CloudExadataInfrastructure.
        :rtype: str
        """
        return self._last_maintenance_run_id

    @last_maintenance_run_id.setter
    def last_maintenance_run_id(self, last_maintenance_run_id):
        """
        Sets the last_maintenance_run_id of this CloudExadataInfrastructure.
        The `OCID`__ of the last maintenance run.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param last_maintenance_run_id: The last_maintenance_run_id of this CloudExadataInfrastructure.
        :type: str
        """
        self._last_maintenance_run_id = last_maintenance_run_id

    @property
    def next_maintenance_run_id(self):
        """
        Gets the next_maintenance_run_id of this CloudExadataInfrastructure.
        The `OCID`__ of the next maintenance run.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The next_maintenance_run_id of this CloudExadataInfrastructure.
        :rtype: str
        """
        return self._next_maintenance_run_id

    @next_maintenance_run_id.setter
    def next_maintenance_run_id(self, next_maintenance_run_id):
        """
        Sets the next_maintenance_run_id of this CloudExadataInfrastructure.
        The `OCID`__ of the next maintenance run.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param next_maintenance_run_id: The next_maintenance_run_id of this CloudExadataInfrastructure.
        :type: str
        """
        self._next_maintenance_run_id = next_maintenance_run_id

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this CloudExadataInfrastructure.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this CloudExadataInfrastructure.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this CloudExadataInfrastructure.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this CloudExadataInfrastructure.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this CloudExadataInfrastructure.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this CloudExadataInfrastructure.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this CloudExadataInfrastructure.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this CloudExadataInfrastructure.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from . import chardet  # noqa: F401
from . import httpsig_cffi  # noqa: F401
from . import jwt  # noqa: F401
from . import idna  # noqa: F401
from . import six  # noqa: F401
from . import urllib3  # noqa: F401
from . import requests  # noqa: F401



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateInstanceAgentCommandDetails(object):
    """
    Create Command Details
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CreateInstanceAgentCommandDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param compartment_id:
            The value to assign to the compartment_id property of this CreateInstanceAgentCommandDetails.
        :type compartment_id: str

        :param execution_time_out_in_seconds:
            The value to assign to the execution_time_out_in_seconds property of this CreateInstanceAgentCommandDetails.
        :type execution_time_out_in_seconds: int

        :param display_name:
            The value to assign to the display_name property of this CreateInstanceAgentCommandDetails.
        :type display_name: str

        :param target:
            The value to assign to the target property of this CreateInstanceAgentCommandDetails.
        :type target: InstanceAgentCommandTarget

        :param content:
            The value to assign to the content property of this CreateInstanceAgentCommandDetails.
        :type content: InstanceAgentCommandContent

        """
        self.swagger_types = {
            'compartment_id': 'str',
            'execution_time_out_in_seconds': 'int',
            'display_name': 'str',
            'target': 'InstanceAgentCommandTarget',
            'content': 'InstanceAgentCommandContent'
        }

        self.attribute_map = {
            'compartment_id': 'compartmentId',
            'execution_time_out_in_seconds': 'executionTimeOutInSeconds',
            'display_name': 'displayName',
            'target': 'target',
            'content': 'content'
        }

        self._compartment_id = None
        self._execution_time_out_in_seconds = None
        self._display_name = None
        self._target = None
        self._content = None

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this CreateInstanceAgentCommandDetails.
        The OCID of the compartment you want to create the command.


        :return: The compartment_id of this CreateInstanceAgentCommandDetails.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this CreateInstanceAgentCommandDetails.
        The OCID of the compartment you want to create the command.


        :param compartment_id: The compartment_id of this CreateInstanceAgentCommandDetails.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def execution_time_out_in_seconds(self):
        """
        **[Required]** Gets the execution_time_out_in_seconds of this CreateInstanceAgentCommandDetails.
        Command execution time limit. Zero means no timeout.


        :return: The execution_time_out_in_seconds of this CreateInstanceAgentCommandDetails.
        :rtype: int
        """
        return self._execution_time_out_in_seconds

    @execution_time_out_in_seconds.setter
    def execution_time_out_in_seconds(self, execution_time_out_in_seconds):
        """
        Sets the execution_time_out_in_seconds of this CreateInstanceAgentCommandDetails.
        Command execution time limit. Zero means no timeout.


        :param execution_time_out_in_seconds: The execution_time_out_in_seconds of this CreateInstanceAgentCommandDetails.
        :type: int
        """
        self._execution_time_out_in_seconds = execution_time_out_in_seconds

    @property
    def display_name(self):
        """
        Gets the display_name of this CreateInstanceAgentCommandDetails.
        A user-friendly name for the command. It does not have to be unique.
        Avoid entering confidential information.
        Example: `Database Backup Command`


        :return: The display_name of this CreateInstanceAgentCommandDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this CreateInstanceAgentCommandDetails.
        A user-friendly name for the command. It does not have to be unique.
        Avoid entering confidential information.
        Example: `Database Backup Command`


        :param display_name: The display_name of this CreateInstanceAgentCommandDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def target(self):
        """
        **[Required]** Gets the target of this CreateInstanceAgentCommandDetails.

        :return: The target of this CreateInstanceAgentCommandDetails.
        :rtype: InstanceAgentCommandTarget
        """
        return self._target

    @target.setter
    def target(self, target):
        """
        Sets the target of this CreateInstanceAgentCommandDetails.

        :param target: The target of this CreateInstanceAgentCommandDetails.
        :type: InstanceAgentCommandTarget
        """
        self._target = target

    @property
    def content(self):
        """
        **[Required]** Gets the content of this CreateInstanceAgentCommandDetails.

        :return: The content of this CreateInstanceAgentCommandDetails.
        :rtype: InstanceAgentCommandContent
        """
        return self._content

    @content.setter
    def content(self, content):
        """
        Sets the content of this CreateInstanceAgentCommandDetails.

        :param content: The content of this CreateInstanceAgentCommandDetails.
        :type: InstanceAgentCommandContent
        """
        self._content = content

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Condition(object):
    """
    Base condition object
    """

    #: A constant which can be used with the kind property of a Condition.
    #: This constant has a value of "COMPOSITE"
    KIND_COMPOSITE = "COMPOSITE"

    #: A constant which can be used with the kind property of a Condition.
    #: This constant has a value of "SIMPLE"
    KIND_SIMPLE = "SIMPLE"

    def __init__(self, **kwargs):
        """
        Initializes a new Condition object with values from keyword arguments. This class has the following subclasses and if you are using this class as input
        to a service operations then you should favor using a subclass over the base class:

        * :class:`~oci.cloud_guard.models.SimpleCondition`
        * :class:`~oci.cloud_guard.models.CompositeCondition`

        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param kind:
            The value to assign to the kind property of this Condition.
            Allowed values for this property are: "COMPOSITE", "SIMPLE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type kind: str

        """
        self.swagger_types = {
            'kind': 'str'
        }

        self.attribute_map = {
            'kind': 'kind'
        }

        self._kind = None

    @staticmethod
    def get_subtype(object_dictionary):
        """
        Given the hash representation of a subtype of this class,
        use the info in the hash to return the class of the subtype.
        """
        type = object_dictionary['kind']

        if type == 'SIMPLE':
            return 'SimpleCondition'

        if type == 'COMPOSITE':
            return 'CompositeCondition'
        else:
            return 'Condition'

    @property
    def kind(self):
        """
        **[Required]** Gets the kind of this Condition.
        Type of condition object

        Allowed values for this property are: "COMPOSITE", "SIMPLE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The kind of this Condition.
        :rtype: str
        """
        return self._kind

    @kind.setter
    def kind(self, kind):
        """
        Sets the kind of this Condition.
        Type of condition object


        :param kind: The kind of this Condition.
        :type: str
        """
        allowed_values = ["COMPOSITE", "SIMPLE"]
        if not value_allowed_none_or_none_sentinel(kind, allowed_values):
            kind = 'UNKNOWN_ENUM_VALUE'
        self._kind = kind

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class TypeCustomPropertyDetails(object):
    """
    Array of custom property IDs for which we have to associate the custom property to the type
    """

    def __init__(self, **kwargs):
        """
        Initializes a new TypeCustomPropertyDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param custom_property_ids:
            The value to assign to the custom_property_ids property of this TypeCustomPropertyDetails.
        :type custom_property_ids: list[str]

        """
        self.swagger_types = {
            'custom_property_ids': 'list[str]'
        }

        self.attribute_map = {
            'custom_property_ids': 'customPropertyIds'
        }

        self._custom_property_ids = None

    @property
    def custom_property_ids(self):
        """
        Gets the custom_property_ids of this TypeCustomPropertyDetails.
        array of custom property Ids


        :return: The custom_property_ids of this TypeCustomPropertyDetails.
        :rtype: list[str]
        """
        return self._custom_property_ids

    @custom_property_ids.setter
    def custom_property_ids(self, custom_property_ids):
        """
        Sets the custom_property_ids of this TypeCustomPropertyDetails.
        array of custom property Ids


        :param custom_property_ids: The custom_property_ids of this TypeCustomPropertyDetails.
        :type: list[str]
        """
        self._custom_property_ids = custom_property_ids

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ActivityProblemAggregation(object):
    """
    Provides the dimensions and their corresponding count.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ActivityProblemAggregation object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param dimensions_map:
            The value to assign to the dimensions_map property of this ActivityProblemAggregation.
        :type dimensions_map: dict(str, str)

        :param political_location:
            The value to assign to the political_location property of this ActivityProblemAggregation.
        :type political_location: PoliticalLocation

        :param geographical_location:
            The value to assign to the geographical_location property of this ActivityProblemAggregation.
        :type geographical_location: GeographicalLocation

        :param count:
            The value to assign to the count property of this ActivityProblemAggregation.
        :type count: int

        """
        self.swagger_types = {
            'dimensions_map': 'dict(str, str)',
            'political_location': 'PoliticalLocation',
            'geographical_location': 'GeographicalLocation',
            'count': 'int'
        }

        self.attribute_map = {
            'dimensions_map': 'dimensionsMap',
            'political_location': 'politicalLocation',
            'geographical_location': 'geographicalLocation',
            'count': 'count'
        }

        self._dimensions_map = None
        self._political_location = None
        self._geographical_location = None
        self._count = None

    @property
    def dimensions_map(self):
        """
        **[Required]** Gets the dimensions_map of this ActivityProblemAggregation.
        The key-value pairs of dimensions and their names.


        :return: The dimensions_map of this ActivityProblemAggregation.
        :rtype: dict(str, str)
        """
        return self._dimensions_map

    @dimensions_map.setter
    def dimensions_map(self, dimensions_map):
        """
        Sets the dimensions_map of this ActivityProblemAggregation.
        The key-value pairs of dimensions and their names.


        :param dimensions_map: The dimensions_map of this ActivityProblemAggregation.
        :type: dict(str, str)
        """
        self._dimensions_map = dimensions_map

    @property
    def political_location(self):
        """
        **[Required]** Gets the political_location of this ActivityProblemAggregation.

        :return: The political_location of this ActivityProblemAggregation.
        :rtype: PoliticalLocation
        """
        return self._political_location

    @political_location.setter
    def political_location(self, political_location):
        """
        Sets the political_location of this ActivityProblemAggregation.

        :param political_location: The political_location of this ActivityProblemAggregation.
        :type: PoliticalLocation
        """
        self._political_location = political_location

    @property
    def geographical_location(self):
        """
        **[Required]** Gets the geographical_location of this ActivityProblemAggregation.

        :return: The geographical_location of this ActivityProblemAggregation.
        :rtype: GeographicalLocation
        """
        return self._geographical_location

    @geographical_location.setter
    def geographical_location(self, geographical_location):
        """
        Sets the geographical_location of this ActivityProblemAggregation.

        :param geographical_location: The geographical_location of this ActivityProblemAggregation.
        :type: GeographicalLocation
        """
        self._geographical_location = geographical_location

    @property
    def count(self):
        """
        **[Required]** Gets the count of this ActivityProblemAggregation.
        The number of occurences with given dimension/s


        :return: The count of this ActivityProblemAggregation.
        :rtype: int
        """
        return self._count

    @count.setter
    def count(self, count):
        """
        Sets the count of this ActivityProblemAggregation.
        The number of occurences with given dimension/s


        :param count: The count of this ActivityProblemAggregation.
        :type: int
        """
        self._count = count

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DatabaseInsightSummary(object):
    """
    Partial definition of the database insight resource.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new DatabaseInsightSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param database_id:
            The value to assign to the database_id property of this DatabaseInsightSummary.
        :type database_id: str

        :param compartment_id:
            The value to assign to the compartment_id property of this DatabaseInsightSummary.
        :type compartment_id: str

        :param database_name:
            The value to assign to the database_name property of this DatabaseInsightSummary.
        :type database_name: str

        :param database_display_name:
            The value to assign to the database_display_name property of this DatabaseInsightSummary.
        :type database_display_name: str

        :param database_type:
            The value to assign to the database_type property of this DatabaseInsightSummary.
        :type database_type: str

        :param database_version:
            The value to assign to the database_version property of this DatabaseInsightSummary.
        :type database_version: str

        :param database_host_names:
            The value to assign to the database_host_names property of this DatabaseInsightSummary.
        :type database_host_names: list[str]

        :param freeform_tags:
            The value to assign to the freeform_tags property of this DatabaseInsightSummary.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this DatabaseInsightSummary.
        :type defined_tags: dict(str, dict(str, object))

        :param system_tags:
            The value to assign to the system_tags property of this DatabaseInsightSummary.
        :type system_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'database_id': 'str',
            'compartment_id': 'str',
            'database_name': 'str',
            'database_display_name': 'str',
            'database_type': 'str',
            'database_version': 'str',
            'database_host_names': 'list[str]',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'system_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'database_id': 'databaseId',
            'compartment_id': 'compartmentId',
            'database_name': 'databaseName',
            'database_display_name': 'databaseDisplayName',
            'database_type': 'databaseType',
            'database_version': 'databaseVersion',
            'database_host_names': 'databaseHostNames',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'system_tags': 'systemTags'
        }

        self._database_id = None
        self._compartment_id = None
        self._database_name = None
        self._database_display_name = None
        self._database_type = None
        self._database_version = None
        self._database_host_names = None
        self._freeform_tags = None
        self._defined_tags = None
        self._system_tags = None

    @property
    def database_id(self):
        """
        **[Required]** Gets the database_id of this DatabaseInsightSummary.
        The `OCID`__ of the database.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The database_id of this DatabaseInsightSummary.
        :rtype: str
        """
        return self._database_id

    @database_id.setter
    def database_id(self, database_id):
        """
        Sets the database_id of this DatabaseInsightSummary.
        The `OCID`__ of the database.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param database_id: The database_id of this DatabaseInsightSummary.
        :type: str
        """
        self._database_id = database_id

    @property
    def compartment_id(self):
        """
        Gets the compartment_id of this DatabaseInsightSummary.
        The `OCID`__ of the compartment.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this DatabaseInsightSummary.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this DatabaseInsightSummary.
        The `OCID`__ of the compartment.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this DatabaseInsightSummary.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def database_name(self):
        """
        Gets the database_name of this DatabaseInsightSummary.
        The database name. The database name is unique within the tenancy.


        :return: The database_name of this DatabaseInsightSummary.
        :rtype: str
        """
        return self._database_name

    @database_name.setter
    def database_name(self, database_name):
        """
        Sets the database_name of this DatabaseInsightSummary.
        The database name. The database name is unique within the tenancy.


        :param database_name: The database_name of this DatabaseInsightSummary.
        :type: str
        """
        self._database_name = database_name

    @property
    def database_display_name(self):
        """
        Gets the database_display_name of this DatabaseInsightSummary.
        The user-friendly name for the database. The name does not have to be unique.


        :return: The database_display_name of this DatabaseInsightSummary.
        :rtype: str
        """
        return self._database_display_name

    @database_display_name.setter
    def database_display_name(self, database_display_name):
        """
        Sets the database_display_name of this DatabaseInsightSummary.
        The user-friendly name for the database. The name does not have to be unique.


        :param database_display_name: The database_display_name of this DatabaseInsightSummary.
        :type: str
        """
        self._database_display_name = database_display_name

    @property
    def database_type(self):
        """
        Gets the database_type of this DatabaseInsightSummary.
        Operations Insights internal representation of the database type.


        :return: The database_type of this DatabaseInsightSummary.
        :rtype: str
        """
        return self._database_type

    @database_type.setter
    def database_type(self, database_type):
        """
        Sets the database_type of this DatabaseInsightSummary.
        Operations Insights internal representation of the database type.


        :param database_type: The database_type of this DatabaseInsightSummary.
        :type: str
        """
        self._database_type = database_type

    @property
    def database_version(self):
        """
        Gets the database_version of this DatabaseInsightSummary.
        The version of the database.


        :return: The database_version of this DatabaseInsightSummary.
        :rtype: str
        """
        return self._database_version

    @database_version.setter
    def database_version(self, database_version):
        """
        Sets the database_version of this DatabaseInsightSummary.
        The version of the database.


        :param database_version: The database_version of this DatabaseInsightSummary.
        :type: str
        """
        self._database_version = database_version

    @property
    def database_host_names(self):
        """
        Gets the database_host_names of this DatabaseInsightSummary.
        The hostnames for the database.


        :return: The database_host_names of this DatabaseInsightSummary.
        :rtype: list[str]
        """
        return self._database_host_names

    @database_host_names.setter
    def database_host_names(self, database_host_names):
        """
        Sets the database_host_names of this DatabaseInsightSummary.
        The hostnames for the database.


        :param database_host_names: The database_host_names of this DatabaseInsightSummary.
        :type: list[str]
        """
        self._database_host_names = database_host_names

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this DatabaseInsightSummary.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :return: The freeform_tags of this DatabaseInsightSummary.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this DatabaseInsightSummary.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :param freeform_tags: The freeform_tags of this DatabaseInsightSummary.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this DatabaseInsightSummary.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :return: The defined_tags of this DatabaseInsightSummary.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this DatabaseInsightSummary.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :param defined_tags: The defined_tags of this DatabaseInsightSummary.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def system_tags(self):
        """
        Gets the system_tags of this DatabaseInsightSummary.
        System tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}`


        :return: The system_tags of this DatabaseInsightSummary.
        :rtype: dict(str, dict(str, object))
        """
        return self._system_tags

    @system_tags.setter
    def system_tags(self, system_tags):
        """
        Sets the system_tags of this DatabaseInsightSummary.
        System tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}`


        :param system_tags: The system_tags of this DatabaseInsightSummary.
        :type: dict(str, dict(str, object))
        """
        self._system_tags = system_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateLogAnalyticsEntityTypeDetails(object):
    """
    Log analytics entity type definition to be updated.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateLogAnalyticsEntityTypeDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param category:
            The value to assign to the category property of this UpdateLogAnalyticsEntityTypeDetails.
        :type category: str

        :param properties:
            The value to assign to the properties property of this UpdateLogAnalyticsEntityTypeDetails.
        :type properties: list[EntityTypeProperty]

        """
        self.swagger_types = {
            'category': 'str',
            'properties': 'list[EntityTypeProperty]'
        }

        self.attribute_map = {
            'category': 'category',
            'properties': 'properties'
        }

        self._category = None
        self._properties = None

    @property
    def category(self):
        """
        Gets the category of this UpdateLogAnalyticsEntityTypeDetails.
        Log analytics entity type category. Category will be used for grouping and filtering.


        :return: The category of this UpdateLogAnalyticsEntityTypeDetails.
        :rtype: str
        """
        return self._category

    @category.setter
    def category(self, category):
        """
        Sets the category of this UpdateLogAnalyticsEntityTypeDetails.
        Log analytics entity type category. Category will be used for grouping and filtering.


        :param category: The category of this UpdateLogAnalyticsEntityTypeDetails.
        :type: str
        """
        self._category = category

    @property
    def properties(self):
        """
        Gets the properties of this UpdateLogAnalyticsEntityTypeDetails.
        A single log analytics entity type property definition.


        :return: The properties of this UpdateLogAnalyticsEntityTypeDetails.
        :rtype: list[EntityTypeProperty]
        """
        return self._properties

    @properties.setter
    def properties(self, properties):
        """
        Sets the properties of this UpdateLogAnalyticsEntityTypeDetails.
        A single log analytics entity type property definition.


        :param properties: The properties of this UpdateLogAnalyticsEntityTypeDetails.
        :type: list[EntityTypeProperty]
        """
        self._properties = properties

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateNamespaceDetails(object):
    """
    Properties used in custom property create operations.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CreateNamespaceDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param display_name:
            The value to assign to the display_name property of this CreateNamespaceDetails.
        :type display_name: str

        :param description:
            The value to assign to the description property of this CreateNamespaceDetails.
        :type description: str

        :param is_service_defined:
            The value to assign to the is_service_defined property of this CreateNamespaceDetails.
        :type is_service_defined: bool

        """
        self.swagger_types = {
            'display_name': 'str',
            'description': 'str',
            'is_service_defined': 'bool'
        }

        self.attribute_map = {
            'display_name': 'displayName',
            'description': 'description',
            'is_service_defined': 'isServiceDefined'
        }

        self._display_name = None
        self._description = None
        self._is_service_defined = None

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this CreateNamespaceDetails.
        A user-friendly display name. Does not have to be unique, and it's changeable.
        Avoid entering confidential information.


        :return: The display_name of this CreateNamespaceDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this CreateNamespaceDetails.
        A user-friendly display name. Does not have to be unique, and it's changeable.
        Avoid entering confidential information.


        :param display_name: The display_name of this CreateNamespaceDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def description(self):
        """
        Gets the description of this CreateNamespaceDetails.
        Detailed description of the Namespace.


        :return: The description of this CreateNamespaceDetails.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this CreateNamespaceDetails.
        Detailed description of the Namespace.


        :param description: The description of this CreateNamespaceDetails.
        :type: str
        """
        self._description = description

    @property
    def is_service_defined(self):
        """
        Gets the is_service_defined of this CreateNamespaceDetails.
        If this field is defined by service or by a user


        :return: The is_service_defined of this CreateNamespaceDetails.
        :rtype: bool
        """
        return self._is_service_defined

    @is_service_defined.setter
    def is_service_defined(self, is_service_defined):
        """
        Sets the is_service_defined of this CreateNamespaceDetails.
        If this field is defined by service or by a user


        :param is_service_defined: The is_service_defined of this CreateNamespaceDetails.
        :type: bool
        """
        self._is_service_defined = is_service_defined

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class EstimatePurgeDataSizeResult(object):
    """
    purge data size in bytes
    """

    def __init__(self, **kwargs):
        """
        Initializes a new EstimatePurgeDataSizeResult object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param purge_data_size_in_bytes:
            The value to assign to the purge_data_size_in_bytes property of this EstimatePurgeDataSizeResult.
        :type purge_data_size_in_bytes: int

        """
        self.swagger_types = {
            'purge_data_size_in_bytes': 'int'
        }

        self.attribute_map = {
            'purge_data_size_in_bytes': 'purgeDataSizeInBytes'
        }

        self._purge_data_size_in_bytes = None

    @property
    def purge_data_size_in_bytes(self):
        """
        **[Required]** Gets the purge_data_size_in_bytes of this EstimatePurgeDataSizeResult.
        This is the size of data to be purged in bytes


        :return: The purge_data_size_in_bytes of this EstimatePurgeDataSizeResult.
        :rtype: int
        """
        return self._purge_data_size_in_bytes

    @purge_data_size_in_bytes.setter
    def purge_data_size_in_bytes(self, purge_data_size_in_bytes):
        """
        Sets the purge_data_size_in_bytes of this EstimatePurgeDataSizeResult.
        This is the size of data to be purged in bytes


        :param purge_data_size_in_bytes: The purge_data_size_in_bytes of this EstimatePurgeDataSizeResult.
        :type: int
        """
        self._purge_data_size_in_bytes = purge_data_size_in_bytes

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateDetails(object):
    """
    Details specifying which maintenance update to apply to the cloud VM cluster and which actions are to be performed by the maintenance update. Applies to Exadata Cloud Service instances only.
    """

    #: A constant which can be used with the update_action property of a UpdateDetails.
    #: This constant has a value of "ROLLING_APPLY"
    UPDATE_ACTION_ROLLING_APPLY = "ROLLING_APPLY"

    #: A constant which can be used with the update_action property of a UpdateDetails.
    #: This constant has a value of "NON_ROLLING_APPLY"
    UPDATE_ACTION_NON_ROLLING_APPLY = "NON_ROLLING_APPLY"

    #: A constant which can be used with the update_action property of a UpdateDetails.
    #: This constant has a value of "PRECHECK"
    UPDATE_ACTION_PRECHECK = "PRECHECK"

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param update_id:
            The value to assign to the update_id property of this UpdateDetails.
        :type update_id: str

        :param update_action:
            The value to assign to the update_action property of this UpdateDetails.
            Allowed values for this property are: "ROLLING_APPLY", "NON_ROLLING_APPLY", "PRECHECK"
        :type update_action: str

        """
        self.swagger_types = {
            'update_id': 'str',
            'update_action': 'str'
        }

        self.attribute_map = {
            'update_id': 'updateId',
            'update_action': 'updateAction'
        }

        self._update_id = None
        self._update_action = None

    @property
    def update_id(self):
        """
        Gets the update_id of this UpdateDetails.
        The `OCID`__ of the maintenance update.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The update_id of this UpdateDetails.
        :rtype: str
        """
        return self._update_id

    @update_id.setter
    def update_id(self, update_id):
        """
        Sets the update_id of this UpdateDetails.
        The `OCID`__ of the maintenance update.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param update_id: The update_id of this UpdateDetails.
        :type: str
        """
        self._update_id = update_id

    @property
    def update_action(self):
        """
        Gets the update_action of this UpdateDetails.
        The update action.

        Allowed values for this property are: "ROLLING_APPLY", "NON_ROLLING_APPLY", "PRECHECK"


        :return: The update_action of this UpdateDetails.
        :rtype: str
        """
        return self._update_action

    @update_action.setter
    def update_action(self, update_action):
        """
        Sets the update_action of this UpdateDetails.
        The update action.


        :param update_action: The update_action of this UpdateDetails.
        :type: str
        """
        allowed_values = ["ROLLING_APPLY", "NON_ROLLING_APPLY", "PRECHECK"]
        if not value_allowed_none_or_none_sentinel(update_action, allowed_values):
            raise ValueError(
                "Invalid value for `update_action`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._update_action = update_action

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .abstract_column import AbstractColumn
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class TimeColumn(AbstractColumn):
    """
    Time column returned when the shape of a queries results contsin a time series.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new TimeColumn object with values from keyword arguments. The default value of the :py:attr:`~oci.log_analytics.models.TimeColumn.type` attribute
        of this class is ``TIME_COLUMN`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param type:
            The value to assign to the type property of this TimeColumn.
            Allowed values for this property are: "COLUMN", "CHART_COLUMN", "CHART_DATA_COLUMN", "TIME_COLUMN", "TREND_COLUMN", "CLASSIFY_COLUMN"
        :type type: str

        :param display_name:
            The value to assign to the display_name property of this TimeColumn.
        :type display_name: str

        :param sub_system:
            The value to assign to the sub_system property of this TimeColumn.
            Allowed values for this property are: "LOG"
        :type sub_system: str

        :param values:
            The value to assign to the values property of this TimeColumn.
        :type values: list[FieldValue]

        :param is_list_of_values:
            The value to assign to the is_list_of_values property of this TimeColumn.
        :type is_list_of_values: bool

        :param is_multi_valued:
            The value to assign to the is_multi_valued property of this TimeColumn.
        :type is_multi_valued: bool

        :param is_groupable:
            The value to assign to the is_groupable property of this TimeColumn.
        :type is_groupable: bool

        :param is_evaluable:
            The value to assign to the is_evaluable property of this TimeColumn.
        :type is_evaluable: bool

        :param value_type:
            The value to assign to the value_type property of this TimeColumn.
            Allowed values for this property are: "BOOLEAN", "STRING", "DOUBLE", "FLOAT", "LONG", "INTEGER", "TIMESTAMP", "FACET"
        :type value_type: str

        :param original_display_name:
            The value to assign to the original_display_name property of this TimeColumn.
        :type original_display_name: str

        :param internal_name:
            The value to assign to the internal_name property of this TimeColumn.
        :type internal_name: str

        :param span:
            The value to assign to the span property of this TimeColumn.
        :type span: str

        :param times:
            The value to assign to the times property of this TimeColumn.
        :type times: list[int]

        """
        self.swagger_types = {
            'type': 'str',
            'display_name': 'str',
            'sub_system': 'str',
            'values': 'list[FieldValue]',
            'is_list_of_values': 'bool',
            'is_multi_valued': 'bool',
            'is_groupable': 'bool',
            'is_evaluable': 'bool',
            'value_type': 'str',
            'original_display_name': 'str',
            'internal_name': 'str',
            'span': 'str',
            'times': 'list[int]'
        }

        self.attribute_map = {
            'type': 'type',
            'display_name': 'displayName',
            'sub_system': 'subSystem',
            'values': 'values',
            'is_list_of_values': 'isListOfValues',
            'is_multi_valued': 'isMultiValued',
            'is_groupable': 'isGroupable',
            'is_evaluable': 'isEvaluable',
            'value_type': 'valueType',
            'original_display_name': 'originalDisplayName',
            'internal_name': 'internalName',
            'span': 'span',
            'times': 'times'
        }

        self._type = None
        self._display_name = None
        self._sub_system = None
        self._values = None
        self._is_list_of_values = None
        self._is_multi_valued = None
        self._is_groupable = None
        self._is_evaluable = None
        self._value_type = None
        self._original_display_name = None
        self._internal_name = None
        self._span = None
        self._times = None
        self._type = 'TIME_COLUMN'

    @property
    def span(self):
        """
        Gets the span of this TimeColumn.
        Time span betwwen each series data point.


        :return: The span of this TimeColumn.
        :rtype: str
        """
        return self._span

    @span.setter
    def span(self, span):
        """
        Sets the span of this TimeColumn.
        Time span betwwen each series data point.


        :param span: The span of this TimeColumn.
        :type: str
        """
        self._span = span

    @property
    def times(self):
        """
        Gets the times of this TimeColumn.
        List of timestamps that represent each time stamp in the entire time series even if certain intervals are filtered out of query results.


        :return: The times of this TimeColumn.
        :rtype: list[int]
        """
        return self._times

    @times.setter
    def times(self, times):
        """
        Sets the times of this TimeColumn.
        List of timestamps that represent each time stamp in the entire time series even if certain intervals are filtered out of query results.


        :param times: The times of this TimeColumn.
        :type: list[int]
        """
        self._times = times

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ConfigurationField(object):
    """
    Provide configuration information about the application in the target environment. Application Migration migrates the application to
    the target environment only after you provide this information. The information that you must provide varies depending on the type of
    application that you are migrating.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ConfigurationField object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this ConfigurationField.
        :type name: str

        :param group:
            The value to assign to the group property of this ConfigurationField.
        :type group: str

        :param type:
            The value to assign to the type property of this ConfigurationField.
        :type type: str

        :param value:
            The value to assign to the value property of this ConfigurationField.
        :type value: str

        :param description:
            The value to assign to the description property of this ConfigurationField.
        :type description: str

        :param is_required:
            The value to assign to the is_required property of this ConfigurationField.
        :type is_required: bool

        :param is_mutable:
            The value to assign to the is_mutable property of this ConfigurationField.
        :type is_mutable: bool

        """
        self.swagger_types = {
            'name': 'str',
            'group': 'str',
            'type': 'str',
            'value': 'str',
            'description': 'str',
            'is_required': 'bool',
            'is_mutable': 'bool'
        }

        self.attribute_map = {
            'name': 'name',
            'group': 'group',
            'type': 'type',
            'value': 'value',
            'description': 'description',
            'is_required': 'isRequired',
            'is_mutable': 'isMutable'
        }

        self._name = None
        self._group = None
        self._type = None
        self._value = None
        self._description = None
        self._is_required = None
        self._is_mutable = None

    @property
    def name(self):
        """
        Gets the name of this ConfigurationField.
        The name of the configuration field.


        :return: The name of this ConfigurationField.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ConfigurationField.
        The name of the configuration field.


        :param name: The name of this ConfigurationField.
        :type: str
        """
        self._name = name

    @property
    def group(self):
        """
        Gets the group of this ConfigurationField.
        The name of the group to which this field belongs, if any.


        :return: The group of this ConfigurationField.
        :rtype: str
        """
        return self._group

    @group.setter
    def group(self, group):
        """
        Sets the group of this ConfigurationField.
        The name of the group to which this field belongs, if any.


        :param group: The group of this ConfigurationField.
        :type: str
        """
        self._group = group

    @property
    def type(self):
        """
        Gets the type of this ConfigurationField.
        The type of the configuration field.


        :return: The type of this ConfigurationField.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this ConfigurationField.
        The type of the configuration field.


        :param type: The type of this ConfigurationField.
        :type: str
        """
        self._type = type

    @property
    def value(self):
        """
        Gets the value of this ConfigurationField.
        The value of the field.


        :return: The value of this ConfigurationField.
        :rtype: str
        """
        return self._value

    @value.setter
    def value(self, value):
        """
        Sets the value of this ConfigurationField.
        The value of the field.


        :param value: The value of this ConfigurationField.
        :type: str
        """
        self._value = value

    @property
    def description(self):
        """
        Gets the description of this ConfigurationField.
        Help text to guide the user in setting the configuration value.


        :return: The description of this ConfigurationField.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this ConfigurationField.
        Help text to guide the user in setting the configuration value.


        :param description: The description of this ConfigurationField.
        :type: str
        """
        self._description = description

    @property
    def is_required(self):
        """
        Gets the is_required of this ConfigurationField.
        Indicates whether or not the field is required (defaults to `true`).


        :return: The is_required of this ConfigurationField.
        :rtype: bool
        """
        return self._is_required

    @is_required.setter
    def is_required(self, is_required):
        """
        Sets the is_required of this ConfigurationField.
        Indicates whether or not the field is required (defaults to `true`).


        :param is_required: The is_required of this ConfigurationField.
        :type: bool
        """
        self._is_required = is_required

    @property
    def is_mutable(self):
        """
        Gets the is_mutable of this ConfigurationField.
        Indicates whether or not the field may be modified (defaults to `true`).


        :return: The is_mutable of this ConfigurationField.
        :rtype: bool
        """
        return self._is_mutable

    @is_mutable.setter
    def is_mutable(self, is_mutable):
        """
        Sets the is_mutable of this ConfigurationField.
        Indicates whether or not the field may be modified (defaults to `true`).


        :param is_mutable: The is_mutable of this ConfigurationField.
        :type: bool
        """
        self._is_mutable = is_mutable

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Operator(object):
    """
    An operator defines some data integration semantics in a data flow. It may be reading/writing data or transforming the data.
    """

    #: A constant which can be used with the model_type property of a Operator.
    #: This constant has a value of "SOURCE_OPERATOR"
    MODEL_TYPE_SOURCE_OPERATOR = "SOURCE_OPERATOR"

    #: A constant which can be used with the model_type property of a Operator.
    #: This constant has a value of "FILTER_OPERATOR"
    MODEL_TYPE_FILTER_OPERATOR = "FILTER_OPERATOR"

    #: A constant which can be used with the model_type property of a Operator.
    #: This constant has a value of "JOINER_OPERATOR"
    MODEL_TYPE_JOINER_OPERATOR = "JOINER_OPERATOR"

    #: A constant which can be used with the model_type property of a Operator.
    #: This constant has a value of "AGGREGATOR_OPERATOR"
    MODEL_TYPE_AGGREGATOR_OPERATOR = "AGGREGATOR_OPERATOR"

    #: A constant which can be used with the model_type property of a Operator.
    #: This constant has a value of "PROJECTION_OPERATOR"
    MODEL_TYPE_PROJECTION_OPERATOR = "PROJECTION_OPERATOR"

    #: A constant which can be used with the model_type property of a Operator.
    #: This constant has a value of "TARGET_OPERATOR"
    MODEL_TYPE_TARGET_OPERATOR = "TARGET_OPERATOR"

    #: A constant which can be used with the model_type property of a Operator.
    #: This constant has a value of "DISTINCT_OPERATOR"
    MODEL_TYPE_DISTINCT_OPERATOR = "DISTINCT_OPERATOR"

    #: A constant which can be used with the model_type property of a Operator.
    #: This constant has a value of "SORT_OPERATOR"
    MODEL_TYPE_SORT_OPERATOR = "SORT_OPERATOR"

    def __init__(self, **kwargs):
        """
        Initializes a new Operator object with values from keyword arguments. This class has the following subclasses and if you are using this class as input
        to a service operations then you should favor using a subclass over the base class:

        * :class:`~oci.data_integration.models.Target`
        * :class:`~oci.data_integration.models.Joiner`
        * :class:`~oci.data_integration.models.Distinct`
        * :class:`~oci.data_integration.models.Filter`
        * :class:`~oci.data_integration.models.Aggregator`
        * :class:`~oci.data_integration.models.SortOper`
        * :class:`~oci.data_integration.models.Projection`
        * :class:`~oci.data_integration.models.Source`

        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param model_type:
            The value to assign to the model_type property of this Operator.
            Allowed values for this property are: "SOURCE_OPERATOR", "FILTER_OPERATOR", "JOINER_OPERATOR", "AGGREGATOR_OPERATOR", "PROJECTION_OPERATOR", "TARGET_OPERATOR", "DISTINCT_OPERATOR", "SORT_OPERATOR", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type model_type: str

        :param key:
            The value to assign to the key property of this Operator.
        :type key: str

        :param model_version:
            The value to assign to the model_version property of this Operator.
        :type model_version: str

        :param parent_ref:
            The value to assign to the parent_ref property of this Operator.
        :type parent_ref: ParentReference

        :param name:
            The value to assign to the name property of this Operator.
        :type name: str

        :param description:
            The value to assign to the description property of this Operator.
        :type description: str

        :param object_version:
            The value to assign to the object_version property of this Operator.
        :type object_version: int

        :param input_ports:
            The value to assign to the input_ports property of this Operator.
        :type input_ports: list[InputPort]

        :param output_ports:
            The value to assign to the output_ports property of this Operator.
        :type output_ports: list[OutputPort]

        :param object_status:
            The value to assign to the object_status property of this Operator.
        :type object_status: int

        :param identifier:
            The value to assign to the identifier property of this Operator.
        :type identifier: str

        :param parameters:
            The value to assign to the parameters property of this Operator.
        :type parameters: list[Parameter]

        :param op_config_values:
            The value to assign to the op_config_values property of this Operator.
        :type op_config_values: ConfigValues

        """
        self.swagger_types = {
            'model_type': 'str',
            'key': 'str',
            'model_version': 'str',
            'parent_ref': 'ParentReference',
            'name': 'str',
            'description': 'str',
            'object_version': 'int',
            'input_ports': 'list[InputPort]',
            'output_ports': 'list[OutputPort]',
            'object_status': 'int',
            'identifier': 'str',
            'parameters': 'list[Parameter]',
            'op_config_values': 'ConfigValues'
        }

        self.attribute_map = {
            'model_type': 'modelType',
            'key': 'key',
            'model_version': 'modelVersion',
            'parent_ref': 'parentRef',
            'name': 'name',
            'description': 'description',
            'object_version': 'objectVersion',
            'input_ports': 'inputPorts',
            'output_ports': 'outputPorts',
            'object_status': 'objectStatus',
            'identifier': 'identifier',
            'parameters': 'parameters',
            'op_config_values': 'opConfigValues'
        }

        self._model_type = None
        self._key = None
        self._model_version = None
        self._parent_ref = None
        self._name = None
        self._description = None
        self._object_version = None
        self._input_ports = None
        self._output_ports = None
        self._object_status = None
        self._identifier = None
        self._parameters = None
        self._op_config_values = None

    @staticmethod
    def get_subtype(object_dictionary):
        """
        Given the hash representation of a subtype of this class,
        use the info in the hash to return the class of the subtype.
        """
        type = object_dictionary['modelType']

        if type == 'TARGET_OPERATOR':
            return 'Target'

        if type == 'JOINER_OPERATOR':
            return 'Joiner'

        if type == 'DISTINCT_OPERATOR':
            return 'Distinct'

        if type == 'FILTER_OPERATOR':
            return 'Filter'

        if type == 'AGGREGATOR_OPERATOR':
            return 'Aggregator'

        if type == 'SORT_OPERATOR':
            return 'SortOper'

        if type == 'PROJECTION_OPERATOR':
            return 'Projection'

        if type == 'SOURCE_OPERATOR':
            return 'Source'
        else:
            return 'Operator'

    @property
    def model_type(self):
        """
        **[Required]** Gets the model_type of this Operator.
        The model type of the operator.

        Allowed values for this property are: "SOURCE_OPERATOR", "FILTER_OPERATOR", "JOINER_OPERATOR", "AGGREGATOR_OPERATOR", "PROJECTION_OPERATOR", "TARGET_OPERATOR", "DISTINCT_OPERATOR", "SORT_OPERATOR", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The model_type of this Operator.
        :rtype: str
        """
        return self._model_type

    @model_type.setter
    def model_type(self, model_type):
        """
        Sets the model_type of this Operator.
        The model type of the operator.


        :param model_type: The model_type of this Operator.
        :type: str
        """
        allowed_values = ["SOURCE_OPERATOR", "FILTER_OPERATOR", "JOINER_OPERATOR", "AGGREGATOR_OPERATOR", "PROJECTION_OPERATOR", "TARGET_OPERATOR", "DISTINCT_OPERATOR", "SORT_OPERATOR"]
        if not value_allowed_none_or_none_sentinel(model_type, allowed_values):
            model_type = 'UNKNOWN_ENUM_VALUE'
        self._model_type = model_type

    @property
    def key(self):
        """
        Gets the key of this Operator.
        The key of the object.


        :return: The key of this Operator.
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """
        Sets the key of this Operator.
        The key of the object.


        :param key: The key of this Operator.
        :type: str
        """
        self._key = key

    @property
    def model_version(self):
        """
        Gets the model_version of this Operator.
        The model version of an object.


        :return: The model_version of this Operator.
        :rtype: str
        """
        return self._model_version

    @model_version.setter
    def model_version(self, model_version):
        """
        Sets the model_version of this Operator.
        The model version of an object.


        :param model_version: The model_version of this Operator.
        :type: str
        """
        self._model_version = model_version

    @property
    def parent_ref(self):
        """
        Gets the parent_ref of this Operator.

        :return: The parent_ref of this Operator.
        :rtype: ParentReference
        """
        return self._parent_ref

    @parent_ref.setter
    def parent_ref(self, parent_ref):
        """
        Sets the parent_ref of this Operator.

        :param parent_ref: The parent_ref of this Operator.
        :type: ParentReference
        """
        self._parent_ref = parent_ref

    @property
    def name(self):
        """
        Gets the name of this Operator.
        Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.


        :return: The name of this Operator.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this Operator.
        Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.


        :param name: The name of this Operator.
        :type: str
        """
        self._name = name

    @property
    def description(self):
        """
        Gets the description of this Operator.
        Details about the operator.


        :return: The description of this Operator.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this Operator.
        Details about the operator.


        :param description: The description of this Operator.
        :type: str
        """
        self._description = description

    @property
    def object_version(self):
        """
        Gets the object_version of this Operator.
        The version of the object that is used to track changes in the object instance.


        :return: The object_version of this Operator.
        :rtype: int
        """
        return self._object_version

    @object_version.setter
    def object_version(self, object_version):
        """
        Sets the object_version of this Operator.
        The version of the object that is used to track changes in the object instance.


        :param object_version: The object_version of this Operator.
        :type: int
        """
        self._object_version = object_version

    @property
    def input_ports(self):
        """
        Gets the input_ports of this Operator.
        An array of input ports.


        :return: The input_ports of this Operator.
        :rtype: list[InputPort]
        """
        return self._input_ports

    @input_ports.setter
    def input_ports(self, input_ports):
        """
        Sets the input_ports of this Operator.
        An array of input ports.


        :param input_ports: The input_ports of this Operator.
        :type: list[InputPort]
        """
        self._input_ports = input_ports

    @property
    def output_ports(self):
        """
        Gets the output_ports of this Operator.
        An array of output ports.


        :return: The output_ports of this Operator.
        :rtype: list[OutputPort]
        """
        return self._output_ports

    @output_ports.setter
    def output_ports(self, output_ports):
        """
        Sets the output_ports of this Operator.
        An array of output ports.


        :param output_ports: The output_ports of this Operator.
        :type: list[OutputPort]
        """
        self._output_ports = output_ports

    @property
    def object_status(self):
        """
        Gets the object_status of this Operator.
        The status of an object that can be set to value 1 for shallow references across objects, other values reserved.


        :return: The object_status of this Operator.
        :rtype: int
        """
        return self._object_status

    @object_status.setter
    def object_status(self, object_status):
        """
        Sets the object_status of this Operator.
        The status of an object that can be set to value 1 for shallow references across objects, other values reserved.


        :param object_status: The object_status of this Operator.
        :type: int
        """
        self._object_status = object_status

    @property
    def identifier(self):
        """
        Gets the identifier of this Operator.
        Value can only contain upper case letters, underscore, and numbers. It should begin with upper case letter or underscore. The value can be modified.


        :return: The identifier of this Operator.
        :rtype: str
        """
        return self._identifier

    @identifier.setter
    def identifier(self, identifier):
        """
        Sets the identifier of this Operator.
        Value can only contain upper case letters, underscore, and numbers. It should begin with upper case letter or underscore. The value can be modified.


        :param identifier: The identifier of this Operator.
        :type: str
        """
        self._identifier = identifier

    @property
    def parameters(self):
        """
        Gets the parameters of this Operator.
        An array of parameters used in the data flow.


        :return: The parameters of this Operator.
        :rtype: list[Parameter]
        """
        return self._parameters

    @parameters.setter
    def parameters(self, parameters):
        """
        Sets the parameters of this Operator.
        An array of parameters used in the data flow.


        :param parameters: The parameters of this Operator.
        :type: list[Parameter]
        """
        self._parameters = parameters

    @property
    def op_config_values(self):
        """
        Gets the op_config_values of this Operator.

        :return: The op_config_values of this Operator.
        :rtype: ConfigValues
        """
        return self._op_config_values

    @op_config_values.setter
    def op_config_values(self, op_config_values):
        """
        Sets the op_config_values of this Operator.

        :param op_config_values: The op_config_values of this Operator.
        :type: ConfigValues
        """
        self._op_config_values = op_config_values

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateTargetRecipeDetectorRuleDetails(object):
    """
    The details to be updated in TargetDetectorRecipeDetectorRule
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateTargetRecipeDetectorRuleDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param detector_rule_id:
            The value to assign to the detector_rule_id property of this UpdateTargetRecipeDetectorRuleDetails.
        :type detector_rule_id: str

        :param details:
            The value to assign to the details property of this UpdateTargetRecipeDetectorRuleDetails.
        :type details: UpdateTargetDetectorRuleDetails

        """
        self.swagger_types = {
            'detector_rule_id': 'str',
            'details': 'UpdateTargetDetectorRuleDetails'
        }

        self.attribute_map = {
            'detector_rule_id': 'detectorRuleId',
            'details': 'details'
        }

        self._detector_rule_id = None
        self._details = None

    @property
    def detector_rule_id(self):
        """
        **[Required]** Gets the detector_rule_id of this UpdateTargetRecipeDetectorRuleDetails.
        Identifier for DetectorRule.


        :return: The detector_rule_id of this UpdateTargetRecipeDetectorRuleDetails.
        :rtype: str
        """
        return self._detector_rule_id

    @detector_rule_id.setter
    def detector_rule_id(self, detector_rule_id):
        """
        Sets the detector_rule_id of this UpdateTargetRecipeDetectorRuleDetails.
        Identifier for DetectorRule.


        :param detector_rule_id: The detector_rule_id of this UpdateTargetRecipeDetectorRuleDetails.
        :type: str
        """
        self._detector_rule_id = detector_rule_id

    @property
    def details(self):
        """
        **[Required]** Gets the details of this UpdateTargetRecipeDetectorRuleDetails.

        :return: The details of this UpdateTargetRecipeDetectorRuleDetails.
        :rtype: UpdateTargetDetectorRuleDetails
        """
        return self._details

    @details.setter
    def details(self, details):
        """
        Sets the details of this UpdateTargetRecipeDetectorRuleDetails.

        :param details: The details of this UpdateTargetRecipeDetectorRuleDetails.
        :type: UpdateTargetDetectorRuleDetails
        """
        self._details = details

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CustomPropertyTypeUsage(object):
    """
    Object which describes the indivial object stats for every custom property
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CustomPropertyTypeUsage object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param type_id:
            The value to assign to the type_id property of this CustomPropertyTypeUsage.
        :type type_id: str

        :param type_name:
            The value to assign to the type_name property of this CustomPropertyTypeUsage.
        :type type_name: str

        :param count:
            The value to assign to the count property of this CustomPropertyTypeUsage.
        :type count: int

        """
        self.swagger_types = {
            'type_id': 'str',
            'type_name': 'str',
            'count': 'int'
        }

        self.attribute_map = {
            'type_id': 'typeId',
            'type_name': 'typeName',
            'count': 'count'
        }

        self._type_id = None
        self._type_name = None
        self._count = None

    @property
    def type_id(self):
        """
        Gets the type_id of this CustomPropertyTypeUsage.
        Unique type key identifier


        :return: The type_id of this CustomPropertyTypeUsage.
        :rtype: str
        """
        return self._type_id

    @type_id.setter
    def type_id(self, type_id):
        """
        Sets the type_id of this CustomPropertyTypeUsage.
        Unique type key identifier


        :param type_id: The type_id of this CustomPropertyTypeUsage.
        :type: str
        """
        self._type_id = type_id

    @property
    def type_name(self):
        """
        Gets the type_name of this CustomPropertyTypeUsage.
        Name of the type associated with


        :return: The type_name of this CustomPropertyTypeUsage.
        :rtype: str
        """
        return self._type_name

    @type_name.setter
    def type_name(self, type_name):
        """
        Sets the type_name of this CustomPropertyTypeUsage.
        Name of the type associated with


        :param type_name: The type_name of this CustomPropertyTypeUsage.
        :type: str
        """
        self._type_name = type_name

    @property
    def count(self):
        """
        Gets the count of this CustomPropertyTypeUsage.
        Number of objects associated with this type


        :return: The count of this CustomPropertyTypeUsage.
        :rtype: int
        """
        return self._count

    @count.setter
    def count(self, count):
        """
        Sets the count of this CustomPropertyTypeUsage.
        Number of objects associated with this type


        :param count: The count of this CustomPropertyTypeUsage.
        :type: int
        """
        self._count = count

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class FacetedSearchDateFilterRequest(object):
    """
    Object with date filter criteria
    """

    def __init__(self, **kwargs):
        """
        Initializes a new FacetedSearchDateFilterRequest object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param field_name:
            The value to assign to the field_name property of this FacetedSearchDateFilterRequest.
        :type field_name: str

        :param time_after:
            The value to assign to the time_after property of this FacetedSearchDateFilterRequest.
        :type time_after: datetime

        :param time_before:
            The value to assign to the time_before property of this FacetedSearchDateFilterRequest.
        :type time_before: datetime

        """
        self.swagger_types = {
            'field_name': 'str',
            'time_after': 'datetime',
            'time_before': 'datetime'
        }

        self.attribute_map = {
            'field_name': 'fieldName',
            'time_after': 'timeAfter',
            'time_before': 'timeBefore'
        }

        self._field_name = None
        self._time_after = None
        self._time_before = None

    @property
    def field_name(self):
        """
        Gets the field_name of this FacetedSearchDateFilterRequest.
        Date field name that needs to be filtered by.


        :return: The field_name of this FacetedSearchDateFilterRequest.
        :rtype: str
        """
        return self._field_name

    @field_name.setter
    def field_name(self, field_name):
        """
        Sets the field_name of this FacetedSearchDateFilterRequest.
        Date field name that needs to be filtered by.


        :param field_name: The field_name of this FacetedSearchDateFilterRequest.
        :type: str
        """
        self._field_name = field_name

    @property
    def time_after(self):
        """
        Gets the time_after of this FacetedSearchDateFilterRequest.
        The date and time the request was created, as described in
        `RFC 3339`__, section 14.29.

        __ https://tools.ietf.org/rfc/rfc3339


        :return: The time_after of this FacetedSearchDateFilterRequest.
        :rtype: datetime
        """
        return self._time_after

    @time_after.setter
    def time_after(self, time_after):
        """
        Sets the time_after of this FacetedSearchDateFilterRequest.
        The date and time the request was created, as described in
        `RFC 3339`__, section 14.29.

        __ https://tools.ietf.org/rfc/rfc3339


        :param time_after: The time_after of this FacetedSearchDateFilterRequest.
        :type: datetime
        """
        self._time_after = time_after

    @property
    def time_before(self):
        """
        Gets the time_before of this FacetedSearchDateFilterRequest.
        The date and time the request was created, as described in
        `RFC 3339`__, section 14.29.

        __ https://tools.ietf.org/rfc/rfc3339


        :return: The time_before of this FacetedSearchDateFilterRequest.
        :rtype: datetime
        """
        return self._time_before

    @time_before.setter
    def time_before(self, time_before):
        """
        Sets the time_before of this FacetedSearchDateFilterRequest.
        The date and time the request was created, as described in
        `RFC 3339`__, section 14.29.

        __ https://tools.ietf.org/rfc/rfc3339


        :param time_before: The time_before of this FacetedSearchDateFilterRequest.
        :type: datetime
        """
        self._time_before = time_before

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class PeerSummary(object):
    """
    Peer summary information for returning in a list.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new PeerSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param peer_key:
            The value to assign to the peer_key property of this PeerSummary.
        :type peer_key: str

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this PeerSummary.
        :type lifecycle_state: str

        """
        self.swagger_types = {
            'peer_key': 'str',
            'lifecycle_state': 'str'
        }

        self.attribute_map = {
            'peer_key': 'peerKey',
            'lifecycle_state': 'lifecycleState'
        }

        self._peer_key = None
        self._lifecycle_state = None

    @property
    def peer_key(self):
        """
        Gets the peer_key of this PeerSummary.
        Peer identifier


        :return: The peer_key of this PeerSummary.
        :rtype: str
        """
        return self._peer_key

    @peer_key.setter
    def peer_key(self, peer_key):
        """
        Sets the peer_key of this PeerSummary.
        Peer identifier


        :param peer_key: The peer_key of this PeerSummary.
        :type: str
        """
        self._peer_key = peer_key

    @property
    def lifecycle_state(self):
        """
        Gets the lifecycle_state of this PeerSummary.
        The current state of the peer.


        :return: The lifecycle_state of this PeerSummary.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this PeerSummary.
        The current state of the peer.


        :param lifecycle_state: The lifecycle_state of this PeerSummary.
        :type: str
        """
        self._lifecycle_state = lifecycle_state

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
